from setuptools import setup

setup(
        name='karatsuba',
        packages=['karatsuba'],
        description='Fast convolution algorithms with Python types',
        license='MIT',
        author='Thomas Baruchel',
        author_email = 'baruchel@gmx.com',
        version='0.1',
        url='https://github.com/baruchel/karatsuba'
)
